#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes-http
version: 1.0.2
id: pipes-http-1.0.2-6097bd429130c2729dfb14657b2bb810
key: pipes_7S0ONFuPIPK74ElYBkImtB
license: BSD3
copyright: 2014 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library
category: Pipes, Web
author: Gabriel Gonzalez
exposed: True
exposed-modules:
    Pipes.HTTP
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/pipes-http-1.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/pipes-http-1.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/pipes-http-1.0.2
hs-libraries: HSpipes-http-1.0.2-7S0ONFuPIPK74ElYBkImtB
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    http-client-0.4.27.1-bb782af803807428bd58a3e7494afa2a
    http-client-tls-0.2.3-dfa8d8f591f2399ab0bdf7c21e1d9977
    pipes-4.1.8-48aeb04c3fec70e47e537a12d228def1
haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html: /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
